@@ -107,7 +107,7 @@ KScoreDialog::KScoreDialog(int fields, QWidget *parent)
     setWindowTitle( i18n(DEFAULT_GROUP_NAME) );
     setModal( true );
     d->highscoreObject = new KHighscore();
-    d->edit = 0;
+    d->edit = nullptr;
     fields |= Score; //Make 'Score' field automatic (it can be hidden if necessary)
     d->fields = fields;
     d->hiddenFields = 0;
@@ -188,8 +188,8 @@ void KScoreDialog::initFromDifficulty(const KgDifficulty* diff, bool doSetConfig
 {
     QMap<QByteArray, QString> localizedLevelStrings;
     QMap<int, QByteArray> levelWeights;
-    foreach (const KgDifficultyLevel* level, diff->levels())
-    {
+    const auto levels = diff->levels();
+    for (const KgDifficultyLevel* level : levels) {
         localizedLevelStrings.insert(level->key(), level->title());
         levelWeights.insert(level->hardness(), level->key());
     }
@@ -216,7 +216,7 @@ QString KScoreDialog::KScoreDialogPrivate::findTranslatedGroupName(const QByteAr
 {
     const QString lookupResult = translatedGroupNames.value(name);
     //If it wasn't found then just try i18n( to see if it happens to be in the database
-    return lookupResult.isEmpty() ? i18n(name) : lookupResult; //FIXME?
+    return lookupResult.isEmpty() ? i18n(name.constData()) : lookupResult; //FIXME?
 }
 
 void KScoreDialog::setComment(const QString &comment)
@@ -259,8 +259,7 @@ void KScoreDialog::KScoreDialogPrivate::setupDialog()
             keysToConfigure.removeAt(index);
         }
     }
-    foreach(const QByteArray &groupName, keysToConfigure)
-    {
+    for (const QByteArray &groupName : qAsConst(keysToConfigure)) {
         setupGroup(groupName);
     }
 }
@@ -456,8 +455,8 @@ void KScoreDialog::KScoreDialogPrivate::loadScores()
     scores.clear();
 
     QList<QByteArray> groupKeyList; //This will be a list of all the groups in the config file
-    foreach( const QString & groupString, highscoreObject->groupList())
-    {
+    const auto groupStrings = highscoreObject->groupList();
+    for (const QString & groupString : groupStrings) {
         groupKeyList << groupString.toUtf8(); //Convert all the QStrings to QByteArrays
     }
 
@@ -489,8 +488,8 @@ void KScoreDialog::KScoreDialogPrivate::loadScores()
         }
     }
     highscoreObject->setHighscoreGroup(QLatin1String( tempCurrentGroup )); //reset to the user-set group name
-    foreach(const QByteArray &groupKey, scores.keys())
-    {
+    const auto groupKeys = scores.keys();
+    for (const QByteArray &groupKey : groupKeys) {
         if( (scores[groupKey][0].value(Score)==QLatin1String( "-" )) && (scores.size() > 1) && (latest.first != groupKey) )
         {
             qCDebug(GAMES_HIGHSCORE) << "Removing group " << groupKey << " since it's unused.";
@@ -644,7 +643,7 @@ void KScoreDialog::slotGotName()
     d->stack[d->newName.first].at((d->newName.second-1))->setCurrentWidget(label);
     d->stack[d->newName.first].at((d->newName.second-1))->removeWidget(d->edit);
     delete d->edit;
-    d->edit = 0;
+    d->edit = nullptr;
     d->newName = QPair<QByteArray,int>(QByteArray(),-1);
     d->scores[d->configGroup].removeAt(10);
     d->comment.clear();  // hide the congratulations
@@ -661,7 +660,7 @@ void KScoreDialog::slotForgetScore()
     d->stack[d->newName.first].at((d->newName.second-1))->removeWidget(d->edit);
     // delete the editor
     delete d->edit;
-    d->edit = 0;
+    d->edit = nullptr;
     // avoid to recreate the KTextEdit widget
     d->newName = QPair<QByteArray,int>(QByteArray(),-1);
     // delete the highscore to forget
