@@ -46,11 +46,11 @@ class KgThemeProvider::Private
         //this disables the addTheme() lock during rediscoverThemes()
         bool m_inRediscover;
 
-        Private(KgThemeProvider *parent, const QByteArray& key) : q(parent), m_configKey(key), m_currentTheme(0), m_defaultTheme(0), m_inRediscover(false) {}
+        Private(KgThemeProvider *parent, const QByteArray& key) : q(parent), m_configKey(key), m_currentTheme(nullptr), m_defaultTheme(nullptr), m_inRediscover(false) {}
 
         void updateThemeName()
         {
-            emit q->currentThemeNameChanged(q->currentThemeName());
+            Q_EMIT q->currentThemeNameChanged(q->currentThemeName());
         }
 };
 
@@ -102,7 +102,7 @@ void KgThemeProvider::addTheme(KgTheme* theme)
 	//*then* start to work with the currentLevel(). The first call to
 	//currentTheme() will load the previous selection from the config, and the
 	//level list will be considered immutable from this point.
-	Q_ASSERT_X(d->m_currentTheme == 0 || d->m_inRediscover,
+	Q_ASSERT_X(d->m_currentTheme == nullptr || d->m_inRediscover,
 		"KgThemeProvider::addTheme",
 		"Only allowed before currentTheme() is called."
 	);
@@ -141,8 +141,7 @@ const KgTheme* KgThemeProvider::currentTheme() const
 		KConfigGroup cg(KSharedConfig::openConfig(), "KgTheme");
 		const QByteArray id = cg.readEntry(d->m_configKey.data(), QByteArray());
 		//look for a theme with this id
-		foreach (const KgTheme* theme, d->m_themes)
-		{
+		for (const KgTheme* theme : qAsConst(d->m_themes)) {
 			if (theme->identifier() == id)
 			{
 				return d->m_currentTheme = theme;
@@ -159,7 +158,7 @@ void KgThemeProvider::setCurrentTheme(const KgTheme* theme)
 	if (d->m_currentTheme != theme)
 	{
 		d->m_currentTheme = theme;
-		emit currentThemeChanged(theme);
+		Q_EMIT currentThemeChanged(theme);
 	}
 }
 
@@ -196,7 +195,7 @@ void KgThemeProvider::rediscoverThemes()
 		return; //discoverThemes() was never called
 	}
 
-	KgTheme* defaultTheme = NULL;
+	KgTheme* defaultTheme = nullptr;
 
 	d->m_inRediscover = true;
 	const QString defaultFileName = d->m_dtDefaultThemeName + QLatin1String(".desktop");
@@ -207,7 +206,7 @@ void KgThemeProvider::rediscoverThemes()
 		const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.desktop"));
 		for (const QString &file : fileNames) {
 			if (!themePaths.contains(file)) {
-				themePaths.append(dir + '/' + file);
+				themePaths.append(dir + QLatin1Char('/') + file);
 			}
 		}
 	}
@@ -215,8 +214,7 @@ void KgThemeProvider::rediscoverThemes()
 	//create themes from result, order default theme at the front (that's not
 	//needed by KgThemeProvider, but nice for the theme selector)
 	QList<KgTheme*> themes;
-	foreach (const QString& themePath, themePaths)
-	{
+	for (const QString& themePath : qAsConst(themePaths)) {
 		const QFileInfo fi(themePath);
 		if (d->m_discoveredThemes.contains(fi.fileName()))
 		{
@@ -267,11 +265,11 @@ void KgThemeProvider::rediscoverThemes()
 		addTheme(theme);
 	}
 
-	if(defaultTheme != NULL)
+	if(defaultTheme != nullptr)
 	{
 		setDefaultTheme(defaultTheme);
 	}
-	else if(d->m_defaultTheme == NULL && themes.count() != 0)
+	else if(d->m_defaultTheme == nullptr && themes.count() != 0)
 	{
 		setDefaultTheme(themes.value(0));
 	}
