@@ -26,7 +26,7 @@
 #include "kmessageio.h"
 
 #include <QWidget>
-#include <qbuffer.h>
+#include <QBuffer>
 #include <QTimer>
 //Added by qt3to4:
 #include <QGraphicsScene>
@@ -40,7 +40,7 @@ class KGameIOPrivate
 {
 public:
   KGameIOPrivate()
-    : mPlayer(0)
+    : mPlayer(nullptr)
   {
   }
 
@@ -101,7 +101,7 @@ void KGameIO::notifyTurn(bool b)
   bool sendit=false;
   QByteArray buffer;
   QDataStream stream(&buffer, QIODevice::WriteOnly);
-  emit signalPrepareTurn(stream, b, this, &sendit);
+  Q_EMIT signalPrepareTurn(stream, b, this, &sendit);
   if (sendit)
   {
     QDataStream ostream(buffer);
@@ -115,7 +115,7 @@ KGame* KGameIO::game() const
 {
   if (!player())
   {
-    return 0;
+    return nullptr;
   }
   return player()->game();
 }
@@ -144,7 +144,7 @@ class KGameKeyIOPrivate
 };
 
 KGameKeyIO::KGameKeyIO(QWidget *parent) 
-   : KGameIO(), d(0)
+   : KGameIO(), d(nullptr)
 {
   if (parent)
   {
@@ -180,7 +180,7 @@ bool KGameKeyIO::eventFilter( QObject *o, QEvent *e )
      QByteArray buffer;
      QDataStream stream(&buffer,QIODevice::WriteOnly);
      bool eatevent=false;
-     emit signalKeyEvent(this,stream,k,&eatevent);
+     Q_EMIT signalKeyEvent(this,stream,k,&eatevent);
      QDataStream msg(buffer);
 
      if (eatevent && sendInput(msg))
@@ -199,7 +199,7 @@ class KGameMouseIOPrivate
 };
 
 KGameMouseIO::KGameMouseIO(QWidget *parent,bool trackmouse) 
-   : KGameIO(), d(0)
+   : KGameIO(), d(nullptr)
 {
   if (parent)
   {
@@ -210,7 +210,7 @@ KGameMouseIO::KGameMouseIO(QWidget *parent,bool trackmouse)
 }
 
 KGameMouseIO::KGameMouseIO(QGraphicsScene *parent,bool /*trackmouse*/) 
-   : KGameIO(), d(0)
+   : KGameIO(), d(nullptr)
 {
   if (parent)
   {
@@ -268,7 +268,7 @@ bool KGameMouseIO::eventFilter( QObject *o, QEvent *e )
      QByteArray buffer;
      QDataStream stream(&buffer,QIODevice::WriteOnly);
      bool eatevent=false;
-     emit signalMouseEvent(this,stream,k,&eatevent);
+     Q_EMIT signalMouseEvent(this,stream,k,&eatevent);
 //     qCDebug(GAMES_PRIVATE_KGAME) << "################# eatevent=" << eatevent;
      QDataStream msg(buffer);
      if (eatevent && sendInput(msg))
@@ -289,7 +289,7 @@ public:
   {
     //mMessageServer = 0;
     //mMessageClient = 0;
-    mProcessIO=0;
+    mProcessIO=nullptr;
   }
   //KMessageServer *mMessageServer;
   //KMessageClient *mMessageClient;
@@ -334,7 +334,7 @@ KGameProcessIO::~KGameProcessIO()
   if (d->mProcessIO)
   {
     delete d->mProcessIO;
-    d->mProcessIO=0;
+    d->mProcessIO=nullptr;
   }
   delete d;
 }
@@ -356,7 +356,7 @@ void KGameProcessIO::initIO(KPlayer *p)
   {
     qint16 id = p->userId();
     stream << id;
-    emit signalIOAdded(this,stream,p,&sendit);
+    Q_EMIT signalIOAdded(this,stream,p,&sendit);
     if (sendit )
     {
       quint32 sender = p->id();
@@ -377,7 +377,7 @@ void KGameProcessIO::notifyTurn(bool b)
   QByteArray buffer;
   QDataStream stream(&buffer,QIODevice::WriteOnly);
   stream << (qint8)b;
-  emit signalPrepareTurn(stream,b,this,&sendit);
+  Q_EMIT signalPrepareTurn(stream,b,this,&sendit);
   if (sendit)
   {
     quint32 sender=player()->id();
@@ -448,7 +448,7 @@ void KGameProcessIO::receivedMessage(const QByteArray& receiveBuffer)
 // This is a dummy message which allows us the process to talk with its owner
   if (msgid==KGameMessage::IdProcessQuery)
   {
-    emit signalProcessQuery(ostream,this);
+    Q_EMIT signalProcessQuery(ostream,this);
   }
   else if (player())
   {
@@ -482,7 +482,7 @@ public:
 
     mPauseCounter = 0;
 
-    mAdvanceTimer = 0;
+    mAdvanceTimer = nullptr;
   }
   int mAdvanceCounter;
   int mReactionPeriod;
@@ -574,7 +574,7 @@ void KGameComputerIO::advance()
 
 void KGameComputerIO::reaction()
 {
-  emit signalReaction();
+  Q_EMIT signalReaction();
 }
 
 
