@@ -20,8 +20,8 @@
 #ifndef __KMESSAGECLIENT_H__
 #define __KMESSAGECLIENT_H__
 
-#include <QtCore/QObject>
-#include <QtCore/QString>
+#include <QObject>
+#include <QString>
 
 #include "libkdegamesprivate_export.h"
 class KMessageIO;
@@ -30,7 +30,7 @@ class KMessageClientPrivate;
 
 /**
   \class KMessageClient kmessageclient.h <KGame/KMessageClient>
-  
+
   @short A client to connect to a KMessageServer
 
   This class implements a client that can connect to a KMessageServer object.
@@ -60,7 +60,7 @@ public:
     Creates an unconnected KMessageClient object. Use setServer() later to connect to a
     KMessageServer object.
   */
-  KMessageClient (QObject *parent = 0);
+  explicit KMessageClient (QObject *parent = nullptr);
 
   /**
     Destructor.
@@ -106,7 +106,7 @@ public:
     on the given host, listening on the specified port.
 
     If we were already connected, the old connection is closed.
-    @param host The name of the host to connect to. Must be either a hostname which can 
+    @param host The name of the host to connect to. Must be either a hostname which can
     be resolved to an IP or just an IP
     @param port The port to connect to
   */
@@ -221,7 +221,7 @@ public:
   void sendForward (const QByteArray &msg, const QList <quint32> &clients);
 
   /**
-    Sends a message to a single client. This is a convenieance method. It calls
+    Sends a message to a single client. This is a convenience method. It calls
     sendForward (const QByteArray &msg, const QValueList &ltquint32> &clients)
     with a list containing only one client ID.
 
@@ -242,7 +242,7 @@ public:
   void lock();
 
   /**
-    Deliver every message that was delayed by lock() and actually deliver 
+    Deliver every message that was delayed by lock() and actually deliver
     all messages that get received from now on.
    */
   void unlock();
@@ -284,7 +284,7 @@ Q_SIGNALS:
     use this e.g. to send a reply message to only that client.
 
     receivers contains the list of the clients that got the message. (If this list
-    only contains one number, this will be your client ID, and it was exclusivly
+    only contains one number, this will be your client ID, and it was exclusively
     sent to you.)
 
     If you don't want to distinguish between broadcast and forward messages and
@@ -334,7 +334,7 @@ Q_SIGNALS:
     This signal is emitted when another client has connected
     to the server. Connect to this method if that clients needs initialization.
     This should usually only be done in one client, e.g. the admin client.
-    @param clientID The ID of the client that has newly connectd.
+    @param clientID The ID of the client that has newly connected.
   */
   void eventClientConnected (quint32 clientID);
 
@@ -364,7 +364,7 @@ Q_SIGNALS:
 
 protected:
   /**
-    This slot is called from processIncomingMessage or 
+    This slot is called from processIncomingMessage or
     processFirstMessage, depending on whether the client is locked or a delayed
     message is still here (see lock)
 
@@ -401,7 +401,7 @@ protected Q_SLOTS:
   virtual void processIncomingMessage (const QByteArray &msg);
 
   /**
-    Called from unlock() (using QTimer::singleShot) until all delayed 
+    Called from unlock() (using QTimer::singleShot) until all delayed
     messages are delivered.
   */
   void processFirstMessage();
