@@ -23,7 +23,7 @@
 
 #include "kmessageio.h"
 #include <QTcpSocket>
-#include <kprocess.h>
+#include <KProcess>
 #include <QFile>
 #include <QDataStream>
 // ----------------------- KMessageIO -------------------------
@@ -141,7 +141,7 @@ void KMessageSocket::processNewData ()
       str.readRawData (msg.data(), mNextBlockLength);
 
       // send the received message
-      emit received (msg);
+      Q_EMIT received (msg);
 
       // Waiting for the header of the next message
       mAwaitingHeader = true;
@@ -153,7 +153,12 @@ void KMessageSocket::processNewData ()
 
 void KMessageSocket::initSocket ()
 {
-  connect(mSocket, static_cast<void (QTcpSocket::*)(QAbstractSocket::SocketError)>(&QTcpSocket::error), this, &KMessageSocket::connectionBroken);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+  connect(mSocket, &QTcpSocket::errorOccurred,
+#else
+  connect(mSocket, QOverload<QAbstractSocket::SocketError>::of(&QTcpSocket::error),
+#endif
+          this, &KMessageSocket::connectionBroken);
   connect(mSocket, &QTcpSocket::disconnected, this, &KMessageSocket::connectionBroken);
   connect(mSocket, &QTcpSocket::readyRead, this, &KMessageSocket::processNewData);
   mAwaitingHeader = true;
@@ -174,7 +179,7 @@ QString KMessageSocket::peerName () const
 // ----------------------KMessageDirect -----------------------
 
 KMessageDirect::KMessageDirect (KMessageDirect *partner, QObject *parent)
-  : KMessageIO (parent), mPartner (0)
+  : KMessageIO (parent), mPartner (nullptr)
 {
   // 0 as first parameter leaves the object unconnected
   if (!partner)
@@ -198,20 +203,20 @@ KMessageDirect::~KMessageDirect ()
 {
   if (mPartner)
   {
-    mPartner->mPartner = 0;
-    emit mPartner->connectionBroken();
+    mPartner->mPartner = nullptr;
+    Q_EMIT mPartner->connectionBroken();
   }
 }
 
 bool KMessageDirect::isConnected () const
 {
-  return mPartner != 0;
+  return mPartner != nullptr;
 }
 
 void KMessageDirect::send (const QByteArray &msg)
 {
   if (mPartner)
-    emit mPartner->received (msg);
+    Q_EMIT mPartner->received (msg);
   else
     qCCritical(GAMES_PRIVATE_KGAME) << ": Not yet connected!";
 }
@@ -226,7 +231,7 @@ KMessageProcess::~KMessageProcess()
   {
     mProcess->kill();
     mProcess->deleteLater();
-    mProcess=0;
+    mProcess=nullptr;
     // Maybe todo: delete mSendBuffer
   }
 }
@@ -246,7 +251,7 @@ KMessageProcess::KMessageProcess(QObject *parent, const QString& file) : KMessag
   connect(mProcess, &KProcess::readyReadStandardError, this, &KMessageProcess::slotReceivedStderr);
   connect(mProcess, static_cast<void (KProcess::*)(int, QProcess::ExitStatus)>(&KProcess::finished), this, &KMessageProcess::slotProcessExited);
   mProcess->start();
-  mSendBuffer=0;
+  mSendBuffer=nullptr;
   mReceiveCount=0;
   mReceiveBuffer.resize(1024);
 }
@@ -264,7 +269,7 @@ void KMessageProcess::send(const QByteArray &msg)
   qCDebug(GAMES_PRIVATE_KGAME) << "@@@KMessageProcess:: SEND("<<msg.size()<<") to process";
   unsigned int size=msg.size()+2*sizeof(long);
 
-  if (mProcess == 0) {
+  if (mProcess == nullptr) {
     qCDebug(GAMES_PRIVATE_KGAME) << "@@@KMessageProcess:: cannot write to stdin, no process available";
     return;
   }
@@ -296,7 +301,7 @@ void KMessageProcess::slotReceivedStderr()
     ba.chop( 1 );   // remove QLatin1Char( '\n' )
 
     qCDebug(GAMES_PRIVATE_KGAME) << "KProcess (" << ba.size() << "):" << ba.constData();
-    emit signalReceivedStderr(QLatin1String( ba ));
+    Q_EMIT signalReceivedStderr(QLatin1String( ba ));
     ba.clear();
   };
 }
@@ -340,7 +345,7 @@ void KMessageProcess::slotReceivedStdout()
 
       std::copy(mReceiveBuffer.begin()+2*sizeof(long),mReceiveBuffer.begin()+len, msg.begin());
 //       msg.duplicate(mReceiveBuffer.data()+2*sizeof(long),len-2*sizeof(long));
-      emit received(msg);
+      Q_EMIT received(msg);
      // msg.resetRawData(mReceiveBuffer.data()+2*sizeof(long),len-2*sizeof(long));
       // Shift buffer
       if (len<mReceiveCount)
@@ -356,9 +361,9 @@ void KMessageProcess::slotReceivedStdout()
 void KMessageProcess::slotProcessExited(int exitCode, QProcess::ExitStatus)
 {
   qCDebug(GAMES_PRIVATE_KGAME) << "Process exited (slot) with code" << exitCode;
-  emit connectionBroken();
+  Q_EMIT connectionBroken();
   delete mProcess;
-  mProcess=0;
+  mProcess=nullptr;
 }
 
 
